//
//  ViewController.swift
//  MultipeerMac
//
//  Created by Felix Wehnert on 20.09.16.
//  Copyright © 2016 Felix Wehnert. All rights reserved.
//

import Cocoa
import MultipeerConnectivity

class MacViewController: NSViewController, MCControllerProtocol, NSTextFieldDelegate {

    @IBOutlet weak var peerLabel: NSTextField!
    @IBOutlet var textView: NSTextView!
    @IBOutlet weak var writeField: NSTextField!
    
    var mcController: MCController?
    var mcBrowser: MCBrowserViewController?
    var mcAdvertiserAssistant: MCAdvertiserAssistant?
    
    
    override func viewDidLoad() {
        super.viewDidLoad()

        self.writeField.delegate = self
        
        mcController = MCController(displayName: Host().localizedName)
        mcController!.delegate = self
        
        self.peerLabel.stringValue = mcController!.peerID.displayName
    
        // Do any additional setup after loading the view.
    }
    
    @IBAction func start(_ sender: NSButton) {
        mcAdvertiserAssistant!.start()
    }
    
    @IBAction func search(_ sender: NSButton) {
    self.presentViewControllerAsSheet(mcBrowser!)
    }
    
    func stateChanged(state: MCSessionState, peer: MCPeerID) {
        var message: String
        switch state {
        case .connected:
            message = "\(peer) joined the conversation"
        case .connecting:
            message = "\(peer) tries to join the conversation"
        case .notConnected:
            message = "\(peer) left or failed to join the conversation"
        }
        
        append(message)
        
        self.peerLabel.stringValue = "\(mcController!.peerID) (you) with \(mcController!.mcSession.connectedPeers.map({$0.displayName}).joined(separator: ", "))"
    }
    
    func stringRecieved(recievedString string: String, fromPeer peer: MCPeerID) {
        append("\(peer): \(string)")
    }

    
    @IBAction func send(_ sender: NSTextField) {
        mcController?.sendString(string: sender.stringValue)
        append("\(self.mcController!.peerID): "+sender.stringValue)
        sender.stringValue = ""
    }
    
    func append(_ text: String) {
        self.textView.string!.append(text+"\n")
    }
    
}

